# nh3

![CI](https://github.com/messense/nh3/workflows/CI/badge.svg)
[![PyPI](https://img.shields.io/pypi/v/nh3.svg)](https://pypi.org/project/nh3)

[ammonia](https://github.com/rust-ammonia/ammonia) Python binding.

## Installation

```bash
pip install nh3
```

## Usage

```python
import nh3

print(nh3.clean("<b><img src=\"\">I'm not trying to XSS you</b>"))
```

## License

This work is released under the MIT license. A copy of the license is provided in the [LICENSE](./LICENSE) file.
